@@ -1,10 +1,12 @@
 /* GEOS wrapper functions operating on WKT geometries
    Called via GDAL ogr headers, requires GDAL built against GEOS.
-   Chris Toney <chris.toney at usda.gov> */
+
+   Chris Toney <chris.toney at usda.gov>
+   Copyright (c) 2023-2024 gdalraster authors
+*/
 
 #include "cpl_conv.h"
 #include "ogr_api.h"
-#include "ogr_core.h"
 #include "ogr_spatialref.h"
 #include "ogr_srs_api.h"
 
@@ -13,7 +15,7 @@
 //' get GEOS version
 //' @noRd
 // [[Rcpp::export(name = ".getGEOSVersion")]]
-std::vector<int> _getGEOSVersion() {
+std::vector<int> getGEOSVersion() {
     int major, minor, patch;
     major = minor = patch = NA_INTEGER;
 #if GDAL_VERSION_NUM >= 3040000
@@ -60,7 +62,7 @@ bool has_geos() {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_create")]]
-std::string _g_create(Rcpp::NumericMatrix xy, std::string geom_type) {
+std::string g_create(Rcpp::NumericMatrix xy, std::string geom_type) {
 // Create a geometry from a list of points (vertices).
 // Currently for POINT, MULTIPOINT, LINESTRING, POLYGON.
 // Only simple polygons composed of one ring are supported.
@@ -167,7 +169,7 @@ std::string _g_create(Rcpp::NumericMatrix xy, std::string geom_type) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_add_geom")]]
-std::string _g_add_geom(std::string sub_geom, std::string container) {
+std::string g_add_geom(std::string sub_geom, std::string container) {
 // Add a geometry to a geometry container.
 // LINEARRING (as POLYGON) to POLYGON, POINT to MULTIPOINT, LINESTRING to
 // MULTILINESTRING, or POLYGON to MULTIPOLYGON
@@ -175,8 +177,8 @@ std::string _g_add_geom(std::string sub_geom, std::string container) {
     OGRGeometryH hSubGeom = nullptr;
     OGRGeometryH hGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_sub = (char*) sub_geom.c_str();
-    char* pszWKT_container = (char*) container.c_str();
+    char *pszWKT_sub = const_cast<char *>(sub_geom.c_str());
+    char *pszWKT_container = const_cast<char *>(container.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_sub, nullptr, &hSubGeom);
     if (err != OGRERR_NONE || hSubGeom == nullptr) {
@@ -233,7 +235,7 @@ std::string _g_add_geom(std::string sub_geom, std::string container) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_is_valid")]]
-bool _g_is_valid(std::string geom) {
+bool g_is_valid(std::string geom) {
 // Test if the geometry is valid.
 // This function is built on the GEOS library, check it for the definition
 // of the geometry operation. If OGR is built without the GEOS library,
@@ -241,7 +243,7 @@ bool _g_is_valid(std::string geom) {
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -258,12 +260,12 @@ bool _g_is_valid(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_is_empty")]]
-bool _g_is_empty(std::string geom) {
+bool g_is_empty(std::string geom) {
 // Test if the geometry is empty.
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -280,12 +282,12 @@ bool _g_is_empty(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_name")]]
-std::string _g_name(std::string geom) {
+std::string g_name(std::string geom) {
 // extract the geometry type name from a WKT geometry
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -306,7 +308,7 @@ std::string _g_name(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_intersects")]]
-bool _g_intersects(std::string this_geom, std::string other_geom) {
+bool g_intersects(std::string this_geom, std::string other_geom) {
 // Determines whether two geometries intersect. If GEOS is enabled, then this
 // is done in rigorous fashion otherwise TRUE is returned if the envelopes
 // (bounding boxes) of the two geometries overlap.
@@ -314,8 +316,8 @@ bool _g_intersects(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -341,7 +343,7 @@ bool _g_intersects(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_equals")]]
-bool _g_equals(std::string this_geom, std::string other_geom) {
+bool g_equals(std::string this_geom, std::string other_geom) {
 // Returns TRUE if two geometries are equivalent.
 // This operation implements the SQL/MM ST_OrderingEquals() operation.
 // The comparison is done in a structural way, that is to say that the
@@ -353,8 +355,8 @@ bool _g_equals(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -380,10 +382,10 @@ bool _g_equals(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_disjoint")]]
-bool _g_disjoint(std::string this_geom, std::string other_geom) {
+bool g_disjoint(std::string this_geom, std::string other_geom) {
 // Tests if this geometry and the other geometry are disjoint.
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -392,8 +394,8 @@ bool _g_disjoint(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -419,10 +421,10 @@ bool _g_disjoint(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_touches")]]
-bool _g_touches(std::string this_geom, std::string other_geom) {
+bool g_touches(std::string this_geom, std::string other_geom) {
 // Tests if this geometry and the other geometry are touching.
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -431,8 +433,8 @@ bool _g_touches(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -458,10 +460,10 @@ bool _g_touches(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_contains")]]
-bool _g_contains(std::string this_geom, std::string other_geom) {
+bool g_contains(std::string this_geom, std::string other_geom) {
 // Tests if this geometry contains the other geometry.
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -470,8 +472,8 @@ bool _g_contains(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -497,10 +499,10 @@ bool _g_contains(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_within")]]
-bool _g_within(std::string this_geom, std::string other_geom) {
+bool g_within(std::string this_geom, std::string other_geom) {
 // Tests if this geometry is within the other geometry.
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -509,8 +511,8 @@ bool _g_within(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -536,10 +538,10 @@ bool _g_within(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_crosses")]]
-bool _g_crosses(std::string this_geom, std::string other_geom) {
+bool g_crosses(std::string this_geom, std::string other_geom) {
 // Tests if this geometry and the other geometry are crossing.
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -548,8 +550,8 @@ bool _g_crosses(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -575,12 +577,12 @@ bool _g_crosses(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_overlaps")]]
-bool _g_overlaps(std::string this_geom, std::string other_geom) {
+bool g_overlaps(std::string this_geom, std::string other_geom) {
 // Tests if this geometry and the other geometry overlap, that is their
 // intersection has a non-zero area (they have some but not all points in
 // common).
 // Geometry validity is not checked. In case you are unsure of the validity
-// of the input geometries, call _g_is_valid() before, otherwise the result
+// of the input geometries, call g_is_valid() before, otherwise the result
 // might be wrong.
 // This function is built on the GEOS library, check it for the definition of
 // the geometry operation. If OGR is built without the GEOS library, this
@@ -589,8 +591,8 @@ bool _g_overlaps(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -620,7 +622,7 @@ bool _g_overlaps(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_buffer")]]
-std::string _g_buffer(std::string geom, double dist, int quad_segs = 30) {
+std::string g_buffer(std::string geom, double dist, int quad_segs = 30) {
 // Compute buffer of geometry.
 
 // Builds a new geometry containing the buffer region around the geometry on
@@ -637,7 +639,7 @@ std::string _g_buffer(std::string geom, double dist, int quad_segs = 30) {
     OGRGeometryH hGeom = nullptr;
     OGRGeometryH hBufferGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -671,9 +673,9 @@ std::string _g_buffer(std::string geom, double dist, int quad_segs = 30) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_intersection")]]
-std::string _g_intersection(std::string this_geom, std::string other_geom) {
+std::string g_intersection(std::string this_geom, std::string other_geom) {
 // Generates a new geometry which is the region of intersection of the two
-// geometries operated on. The _g_intersects() function can be used to test
+// geometries operated on. The g_intersects() function can be used to test
 // if two geometries intersect.
 // Geometry validity is not checked. In case you are unsure of the validity
 // of the input geometries, call IsValid() before, otherwise the result might
@@ -685,8 +687,8 @@ std::string _g_intersection(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -716,7 +718,7 @@ std::string _g_intersection(std::string this_geom, std::string other_geom) {
     OGR_G_ExportToWkt(hGeom, &pszWKT_out);
     std::string wkt_out = "";
     if (pszWKT_out != nullptr) {
-        wkt_out = pszWKT_out;
+        wkt_out = std::string(pszWKT_out);
         CPLFree(pszWKT_out);
     }
     OGR_G_DestroyGeometry(hGeom);
@@ -728,7 +730,7 @@ std::string _g_intersection(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_union")]]
-std::string _g_union(std::string this_geom, std::string other_geom) {
+std::string g_union(std::string this_geom, std::string other_geom) {
 // Generates a new geometry which is the region of union of the two
 // geometries operated on.
 // Geometry validity is not checked. In case you are unsure of the validity
@@ -741,8 +743,8 @@ std::string _g_union(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -784,7 +786,7 @@ std::string _g_union(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_difference")]]
-std::string _g_difference(std::string this_geom, std::string other_geom) {
+std::string g_difference(std::string this_geom, std::string other_geom) {
 // Generates a new geometry which is the region of this geometry with the
 // region of the other geometry removed.
 // Geometry validity is not checked. In case you are unsure of the validity
@@ -797,8 +799,8 @@ std::string _g_difference(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -840,7 +842,7 @@ std::string _g_difference(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_sym_difference")]]
-std::string _g_sym_difference(std::string this_geom, std::string other_geom) {
+std::string g_sym_difference(std::string this_geom, std::string other_geom) {
 // Generates a new geometry which is the symmetric difference of this geometry
 // and the other geometry.
 // Geometry validity is not checked. In case you are unsure of the validity
@@ -853,8 +855,8 @@ std::string _g_sym_difference(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -900,7 +902,7 @@ std::string _g_sym_difference(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_distance")]]
-double _g_distance(std::string this_geom, std::string other_geom) {
+double g_distance(std::string this_geom, std::string other_geom) {
 // Returns the distance between the geometries or -1 if an error occurs.
 // Returns the shortest distance between the two geometries. The distance is
 // expressed into the same unit as the coordinates of the geometries.
@@ -911,8 +913,8 @@ double _g_distance(std::string this_geom, std::string other_geom) {
     OGRGeometryH hGeom_this = nullptr;
     OGRGeometryH hGeom_other = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT_this = (char*) this_geom.c_str();
-    char* pszWKT_other = (char*) other_geom.c_str();
+    char *pszWKT_this = const_cast<char *>(this_geom.c_str());
+    char *pszWKT_other = const_cast<char *>(other_geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT_this, nullptr, &hGeom_this);
     if (err != OGRERR_NONE || hGeom_this == nullptr) {
@@ -939,13 +941,13 @@ double _g_distance(std::string this_geom, std::string other_geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_length")]]
-double _g_length(std::string geom) {
+double g_length(std::string geom) {
 // Computes the length for OGRCurve (LineString) or MultiCurve objects.
 // Undefined for all other geometry types (returns zero).
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -962,13 +964,13 @@ double _g_length(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_area")]]
-double _g_area(std::string geom) {
+double g_area(std::string geom) {
 // Computes the area for an OGRLinearRing, OGRPolygon or OGRMultiPolygon.
 // Undefined for all other geometry types (returns zero).
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -985,7 +987,7 @@ double _g_area(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_centroid")]]
-Rcpp::NumericVector _g_centroid(std::string geom) {
+Rcpp::NumericVector g_centroid(std::string geom) {
 // Returns a vector of ptX, ptY.
 // This method relates to the SFCOM ISurface::get_Centroid() method however
 // the current implementation based on GEOS can operate on other geometry
@@ -999,7 +1001,7 @@ Rcpp::NumericVector _g_centroid(std::string geom) {
 
     OGRGeometryH hGeom = nullptr;
     OGRErr err = OGRERR_NONE;
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
 
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
@@ -1035,7 +1037,7 @@ Rcpp::NumericVector _g_centroid(std::string geom) {
 
 //' @noRd
 // [[Rcpp::export(name = ".g_transform")]]
-std::string _g_transform(std::string geom, std::string srs_from,
+std::string g_transform(std::string geom, std::string srs_from,
         std::string srs_to, bool wrap_date_line = false,
         int date_line_offset = 10) {
 // Returns a transformed geometry as WKT
@@ -1064,7 +1066,7 @@ std::string _g_transform(std::string geom, std::string srs_from,
     OGRGeometryH hGeom2 = nullptr;
     OGRErr err = OGRERR_NONE;
 
-    char* pszWKT = (char*) geom.c_str();
+    char *pszWKT = const_cast<char *>(geom.c_str());
     err = OGR_G_CreateFromWkt(&pszWKT, nullptr, &hGeom);
     if (err != OGRERR_NONE || hGeom == nullptr) {
         if (hGeom != nullptr)
@@ -1093,9 +1095,9 @@ std::string _g_transform(std::string geom, std::string srs_from,
     std::vector<char *> options;
     std::string offset;
     if (wrap_date_line) {
-        options.push_back((char *) "WRAPDATELINE=YES");
+        options.push_back(const_cast<char *>("WRAPDATELINE=YES"));
         offset = "DATELINEOFFSET=" + std::to_string(date_line_offset);
-        options.push_back((char *) offset.c_str());
+        options.push_back(const_cast<char *>(offset.c_str()));
     }
     options.push_back(nullptr);
 
