@@ -3,6 +3,15 @@ test_that("info() prints output to the console", {
     evt_file <- system.file("extdata/storml_evt.tif", package="gdalraster")
     ds <- new(GDALRaster, evt_file, TRUE)
     expect_output(ds$info())
+    # with args
+    ds$infoOptions <- c("-nomd", "-norat", "-noct")
+    expect_output(ds$info())
+    # with invalid arg
+    ds$infoOptions <- "--invalid_arg"
+    expect_error(ds$info())
+    # restore default
+    ds$infoOptions <- ""
+    expect_output(ds$info())
     ds$close()
 })
 
@@ -11,7 +20,13 @@ test_that("infoAsJSON() returns string output", {
     tmp_file <- paste0(tempdir(), "/", "storml_evt_tmp.tif")
     file.copy(evt_file,  tmp_file)
     ds <- new(GDALRaster, tmp_file, TRUE)
-    expect_type(ds$infoAsJSON(), "character")
+    expect_vector(ds$infoAsJSON(), character(), size = 1)
+    expect_true(nchar(ds$infoAsJSON()) > 100)
+    # test passing extra `-json`
+    ds$infoOptions <- "-json"
+    expect_vector(ds$infoAsJSON(), character(), size = 1)
+    expect_true(nchar(ds$infoAsJSON()) > 100)
+
     files <- ds$getFileList()
     on.exit(unlink(files))
     ds$close()
@@ -29,7 +44,7 @@ test_that("dataset parameters are correct", {
     expect_equal(ds$getRasterXSize(), 143)
     expect_equal(ds$getRasterYSize(), 107)
     expect_equal(ds$getGeoTransform(),
-                    c(323476.1,30.0,0.0,5105082.0,0.0,-30.0))
+                 c(323476.1,30.0,0.0,5105082.0,0.0,-30.0))
     expect_equal(ds$bbox(), c(323476.1,5101872.0,327766.1,5105082.0))
     expect_equal(ds$res(), c(30,30))
     expect_equal(ds$dim(), c(143,107,1))
@@ -44,17 +59,23 @@ test_that("dataset parameters are correct", {
     expect_equal(ds_oo$getRasterXSize(), 143)
     expect_equal(ds_oo$getRasterYSize(), 107)
     expect_equal(ds_oo$getGeoTransform(),
-                    c(323476.1,30.0,0.0,5105082.0,0.0,-30.0))
+                 c(323476.1,30.0,0.0,5105082.0,0.0,-30.0))
     expect_equal(ds_oo$bbox(), c(323476.1,5101872.0,327766.1,5105082.0))
     expect_equal(ds_oo$res(), c(30,30))
     expect_equal(ds_oo$dim(), c(143,107,1))
     ds_oo$close()
+
+    # without using shared mode
+    ds_ns <- new(GDALRaster, elev_file, TRUE, NULL, FALSE)
+    expect_equal(ds_ns$getDriverShortName(), "GTiff")
+    ds_ns$close()
 })
 
 test_that("band-level parameters are correct", {
     evt_file <- system.file("extdata/storml_evt.tif", package="gdalraster")
     ds <- new(GDALRaster, evt_file, TRUE)
     expect_equal(ds$getBlockSize(1), c(143,28))
+    expect_equal(ds$getActualBlockSize(1, 0, 0), c(143,28))
     expect_equal(ds$getOverviewCount(1), 0)
     expect_equal(ds$getDataTypeName(1), "Int16")
     expect_equal(ds$getNoDataValue(1), 32767)
@@ -70,16 +91,19 @@ test_that("metadata are correct", {
     ds <- new(GDALRaster, evt_file, TRUE)
     expect_equal(ds$getMetadata(band=0, domain=""), "AREA_OR_POINT=Area")
     expect_equal(ds$getMetadata(band=1, domain=""),
-                "RepresentationType=ATHEMATIC")
+                 "RepresentationType=ATHEMATIC")
     expect_equal(ds$getMetadata(band=0, domain="IMAGE_STRUCTURE"),
-                "INTERLEAVE=BAND")
+                 "INTERLEAVE=BAND")
     expect_equal(ds$getMetadata(band=1, domain="IMAGE_STRUCTURE"), "")
     expect_equal(ds$getMetadataItem(band=0, mdi_name="AREA_OR_POINT",
-                domain=""), "Area")
+                                    domain=""),
+                 "Area")
     expect_equal(ds$getMetadataItem(band=0, "INTERLEAVE",
-                domain="IMAGE_STRUCTURE"), "BAND")
+                                    domain="IMAGE_STRUCTURE"),
+                 "BAND")
     expect_equal(ds$getMetadataItem(band=1, mdi_name="COMPRESSION",
-                domain="IMAGE_STRUCTURE"), "")
+                                    domain="IMAGE_STRUCTURE"),
+                 "")
     expect_equal(length(ds$getMetadataDomainList(band=0)), 3)
     expect_equal(length(ds$getMetadataDomainList(band=1)), 1)
     ds$close()
@@ -93,10 +117,10 @@ test_that("open/close/re-open works", {
     ds$close()
     mod_file <- paste0(tempdir(), "/", "storml_elev_mod.tif")
     rasterFromRaster(srcfile = elev_file,
-                    dstfile = mod_file,
-                    nbands = 1,
-                    dtName = "UInt32",
-                    init = DEFAULT_NODATA[["UInt32"]])
+                     dstfile = mod_file,
+                     nbands = 1,
+                     dtName = "UInt32",
+                     init = DEFAULT_NODATA[["UInt32"]])
     ds <- new(GDALRaster, mod_file, read_only=TRUE)
     expect_true(ds$isOpen())
     expect_true(all(is.na(read_ds(ds))))
@@ -115,6 +139,12 @@ test_that("open/close/re-open works", {
     files <- ds$getFileList()
     on.exit(unlink(files))
     ds$close()
+
+    ds <- new(GDALRaster)
+    ds$setFilename(elev_file)
+    ds$open(TRUE)
+    expect_equal(ds$dim(), dm)
+    ds$close()
 })
 
 test_that("statistics are correct", {
@@ -132,6 +162,14 @@ test_that("statistics are correct", {
         stats <- round(ds$getStatistics(band=1, approx_ok=TRUE, force=FALSE))
         expect_true(all(is.na(stats)))
     }
+
+    # quiet
+    stats <- NULL
+    ds$quiet <- TRUE
+    expect_silent(stats <- ds$getStatistics(band=1, approx_ok=FALSE,
+                                            force=TRUE))
+    expect_equal(round(stats), c(2438, 3046, 2676, 133))
+
     files <- ds$getFileList()
     on.exit(unlink(files))
     ds$close()
@@ -146,6 +184,13 @@ test_that("get histogram works", {
     expect_equal(num_bins, 101)
     num_pixels <- sum(ds$getHistogram(1, -0.5, 100.5, 101, FALSE, FALSE))
     expect_equal(num_pixels, 15301)
+    # quiet
+    num_pixels <- 0
+    ds$quiet <- TRUE
+    expect_silent(num_pixels <- sum(ds$getHistogram(1, -0.5, 100.5, 101,
+                                                    FALSE, FALSE)))
+    expect_equal(num_pixels, 15301)
+
     ds$close()
     deleteDataset(f)
 
@@ -162,7 +207,7 @@ test_that("get histogram works", {
 test_that("floating point I/O works", {
     f <- paste0(tempdir(), "/", "testfloat.tif")
     create(format="GTiff", dst_filename=f, xsize=10, ysize=10,
-            nbands=1, dataType="Float32")
+           nbands=1, dataType="Float32")
     ds <- new(GDALRaster, f, read_only=FALSE)
     set.seed(42)
     z <- runif(10*10)
@@ -191,7 +236,7 @@ test_that("floating point I/O works", {
 test_that("complex I/O works", {
     f <- paste0(tempdir(), "/", "testcomplex.tif")
     create(format="GTiff", dst_filename=f, xsize=10, ysize=10,
-            nbands=1, dataType="CFloat32")
+           nbands=1, dataType="CFloat32")
     ds <- new(GDALRaster, f, read_only=FALSE)
     set.seed(42)
     z <- complex(real = stats::rnorm(100), imaginary = stats::rnorm(100))
@@ -205,6 +250,44 @@ test_that("complex I/O works", {
     ds$close()
 })
 
+test_that("Byte I/O works", {
+    f <- paste0(tempdir(), "/", "testbyte.tif")
+    create(format="GTiff", dst_filename=f, xsize=10, ysize=10,
+           nbands=1, dataType="Byte")
+    ds <- new(GDALRaster, f, read_only=FALSE)
+    set.seed(42)
+    z <- as.raw(sample(100, 100))
+    ds$write(band=1, xoff=0, yoff=0, xsize=10, ysize=10, z)
+
+    ds$open(read_only=TRUE)
+    expect_false(ds$readByteAsRaw)
+    ## read as raw with the temporary setting
+    expect_warning(r_raw <- read_ds(ds, as_raw = TRUE))
+    ## read with to-integer conversion (as default, not affected by 'as_raw')
+    expect_warning(r_int <- read_ds(ds))
+    ## set and read as raw via field
+    ds$readByteAsRaw <- TRUE
+    expect_warning(r_raw1 <- read_ds(ds, as_raw = TRUE))
+
+    deleteDataset(f)
+
+    expect_type(r_int, "integer")
+    expect_type(r_raw, "raw")
+    expect_type(r_raw1, "raw")
+    attributes(r_raw) <- NULL
+    expect_equal(r_raw, z)
+
+    ds$close()
+})
+
+test_that("Byte I/O: warn when data type not compatible", {
+    ## expect a warning when data type is not Byte
+    elev_file <- system.file("extdata/storml_elev.tif", package="gdalraster")
+    ds <- new(GDALRaster, elev_file)
+    expect_warning(read_ds(ds, 1L, 0L, 0L, 2L, 3L, 2L, 3L, as_raw = TRUE))
+    ds$close()
+})
+
 test_that("set unit type, scale and offset works", {
     elev_file <- system.file("extdata/storml_elev.tif", package="gdalraster")
     mod_file <- paste0(tempdir(), "/", "storml_elev_mod.tif")
@@ -228,6 +311,11 @@ test_that("build overviews runs without error", {
     ds <- new(GDALRaster, mod_file, read_only=FALSE)
     expect_no_error(ds$buildOverviews("BILINEAR", c(2,4,8), 0))
     expect_no_error(ds$buildOverviews("NONE", 0, 0))
+    # quiet
+    ds$quiet <- TRUE
+    expect_silent(ds$buildOverviews("BILINEAR", c(2,4,8), 0))
+    expect_silent(ds$buildOverviews("NONE", 0, 0))
+
     files <- ds$getFileList()
     on.exit(unlink(files))
     ds$close()
@@ -237,7 +325,7 @@ test_that("get/set color table works", {
     f <- system.file("extdata/storml_evc.tif", package="gdalraster")
     f2 <- paste0(tempdir(), "/", "storml_evc_ct.tif")
     calc("A", f, dstfile=f2, dtName="UInt16", nodata_value=32767,
-            setRasterNodataValue=TRUE)
+         setRasterNodataValue=TRUE)
     ds <- new(GDALRaster, f2, read_only=FALSE)
     evc_csv <- system.file("extdata/LF20_EVC_220.csv", package="gdalraster")
     vat <- read.csv(evc_csv)
@@ -324,6 +412,14 @@ test_that("get/set default RAT works", {
     expect_equal(attr(rat2$EVT_NAME, "GFU"), "Name")
     expect_equal(attr(rat2$EVT_LF, "GFU"), "Generic")
     expect_equal(attr(rat2$B, "GFU"), "Blue")
+
+    # quiet
+    ds$close()
+    ds$open(TRUE)
+    ds$quiet <- TRUE
+    expect_silent(rat3 <- ds$getDefaultRAT(band=1))
+    expect_equal(nrow(rat2), 24)
+
     ds$close()
     deleteDataset(f)
 })
